@@ -54,12 +54,12 @@ class API(object):
         self.__url_active_users_info = self.__url_base + '/users'
         self.__url_process_status = self.__url_base + '/process_status?process_tokens='
 
-        # New Endpoints
+        # New Endpoints ([X] = Implemented, [-] = Skip)
         self.__url_access_grant = self.__url_base + '/access/grant'                         # [X]
         self.__url_access_revoke = self.__url_base + '/access/revoke'                       # [X]
         self.__url_activate_siren = self.__url_base + '/activate_siren'                     # [ ]
-        self.__url_apptype = self.__url_base + '/apptype'                                   # [ ]
-        self.__url_cameras = self.__url_base + '/cameras'                                   # [ ]
+        self.__url_apptype = self.__url_base + '/apptype'                                   # [-]
+        self.__url_cameras = self.__url_base + '/cameras'                                   # [X]
         self.__url_disable_siren = self.__url_base + '/disable_siren'                       # [ ]
         self.__url_feature_set  = self.__url_base + '/feature_set'                          # [X]
         self.__url_home_automation_devices = self.__url_base + '/home_automation_devices'   # [ ]
@@ -147,6 +147,7 @@ class API(object):
             'Accept': '*/*',
             'User-Agent': self.__user_agent,
             'Accept-Language': 'en-us',
+            'Accept-Encoding': 'gzip',
         }
 
         # Only needed for POST requests
@@ -301,6 +302,10 @@ class API(object):
         """ Get the current alerts. """
         return self.__send_request(self.__url_alerts, request_type='GET')
 
+    def get_cameras(self):
+        """ Get the cameras in the system. """
+        return self.__send_request(self.__url_cameras, request_type='GET')
+
     def get_devices(self):
         """ Get all device specific information. """
         return self.__send_request(self.__url_devices, request_type='GET')
